<?php
namespace Teknisa\MAN\Controllers;

use Teknisa\MAN\Services\PrecosDiferenciadosService;
use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DTO;

class PrecosDiferenciados extends CrudWithParameterBag {
    protected $dataSourceName = 'precosdiferenciados';
    protected $dataSourceNameToFind = 'precosdiferenciadosconsumidores';
    protected $dataSourceNameToFindToo = 'tipoconsumidor';
    protected $dataSourceNameToFindCommaAlso = 'tipospreco';

    protected $parameterBagColumns = array('NRORG');
    /**
     * @var precosDiferenciadosService
     */
    protected $precosDiferenciadosService;

    public function __construct (Manager $dataSourceManager, PrecosDiferenciadosService $precosDiferenciadosService, ParameterBag $parameterBag) {
        $this->precosDiferenciadosService = $precosDiferenciadosService;
        parent::__construct($dataSourceManager, $parameterBag);
    }
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceNameToFind);
        $dataSet = $this->dataSourceManager->findBy($filterData);
        $rows = $dataSet->getRows();
        foreach ($rows as &$row) {
            if ($row['NRTIPOPRECO'] == null){
                $row['NOMEPRECO'] = 'Ambos';
            }
        }
        $newDataSet = new DataSource\DataSet($this->dataSourceNameToFind, $rows);
        $response->addDataSet($newDataSet);

    }

    public function findConsummers(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNameToFindToo;
        parent::find($request, $response);    
    }

    public function findPrices(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceNameToFindCommaAlso);
        $dataSet = $this->dataSourceManager->findBy($filterData);
        $rows = $dataSet->getRows();

        $rows[2] = array('NRTIPOPRECO'=>null, 'NOMEPRECO'=>'Ambos', '__is_new'=>false);
        $newDataSet = new DataSource\DataSet($this->dataSourceNameToFindCommaAlso, $rows);
        $response->addDataSet($newDataSet);
    }

    public function delete(DTO\Request\DataSet $request, DTO\Response $response) {
        foreach ($request->getDataSet()->getRows() as &$row) {

            $row['DTULTATU'] = date("d/m/Y H:i:s");
            if(!isset($row['CDTIPOCONSPD'])) {
                $row['CDTIPOCONSPD'] = "T";
            }
            $row['VRPRECODIA'] = $row['VRPRECODIA']."";
            $numDec = explode(".", $row['VRPRECODIA']);
            $numDec = explode(",", $row['VRPRECODIA']);
            if(!isset($numDec[1])){
                $numDec[1] = 0;
            }
            $row['VRPRECODIA'] = $numDec[0].",".$numDec[1];
            $row['HRINIPRECDIA'] = str_replace(':', '', $row['HRINIPRECDIA']);
            $row['HRFINPRECDIA'] = str_replace(':', '', $row['HRFINPRECDIA']);
            $row['IDPERVALORPR'] =  ($row['IDPERVALORPR'] == 'Valor' || $row['IDPERVALORPR'] == 'V')? 'V' : 'P';
            $row['IDDESCACREPR'] =  ($row['IDDESCACREPR'] == 'Desconto' || $row['IDDESCACREPR'] == 'D')? 'D' : 'A';
            $this->precosDiferenciadosService->atualizaIdativo($row);
        }
    }

    public function save(DTO\Request\DataSet $request, DTO\Response $response) {  
        try{   
            foreach ($request->getDataSet()->getRows() as &$row) {
                if($row['__is_new']){
                    $row['DTINCLUSAO'] = date("d/m/Y H:i:s");
                    if(!isset($row['CDTIPOCONSPD'])) {
                        $row['CDTIPOCONSPD'] = "T";
                    }
                    $row['VRPRECODIA'] = $row['VRPRECODIA']."";
                    $numDec = explode(".", $row['VRPRECODIA']);
                    $numDec = explode(",", $row['VRPRECODIA']);
                    if(!isset($numDec[1])){
                        $numDec[1] = 0;
                    }
                    $row['CDPRPAITABPR'] = $row['CDPRODUTO'];
                    $row['VRPRECODIA'] = $numDec[0].",".$numDec[1];
                    $row['HRINIPRECDIA'] = str_replace(':', '', $row['HRINIPRECDIA']);
                    $row['HRFINPRECDIA'] = str_replace(':', '', $row['HRFINPRECDIA']);
                    $row['IDPERVALORPR'] =  ($row['IDPERVALORPR'] == 'Valor' || $row['IDPERVALORPR'] == 'V')? 'V' : 'P';
                    $row['IDDESCACREPR'] =  ($row['IDDESCACREPR'] == 'Desconto' || $row['IDDESCACREPR'] == 'D')? 'D' : 'A';
                    foreach($row['NRDIASEMANPR'] as $nrdiasemanpr) {
                        $row['__is_new'] = true;
                        $row['NRDIASEMANPR'] = $nrdiasemanpr;
                        $dataSet = $request->getDataSet();
                        $dataSet->setDataSourceName($this->dataSourceName);
                        $persistedRows = $this->dataSourceManager->persist($dataSet);
                    }
                } else if (!$row['__is_new']) {
                    $row['DTULTATU'] = date("d/m/Y H:i:s");
                    if(!isset($row['CDTIPOCONSPD'])) {
                        $row['CDTIPOCONSPD'] = "T";
                    }
                    $row['VRPRECODIA'] = $row['VRPRECODIA']."";
                    $numDec = explode(".", $row['VRPRECODIA']);
                    $numDec = explode(",", $row['VRPRECODIA']);
                    if(!isset($numDec[1])){
                        $numDec[1] = 0;
                    }
                    $row['CDPRPAITABPR'] = $row['CDPRODUTO'];
                    $row['VRPRECODIA'] = $numDec[0].",".$numDec[1];
                    $row['HRINIPRECDIA'] = str_replace(':', '', $row['HRINIPRECDIA']);
                    $row['HRFINPRECDIA'] = str_replace(':', '', $row['HRFINPRECDIA']);
                    $row['IDPERVALORPR'] =  ($row['IDPERVALORPR'] == 'Valor' || $row['IDPERVALORPR'] == 'V')? 'V' : 'P';
                    $row['IDDESCACREPR'] =  ($row['IDDESCACREPR'] == 'Desconto' || $row['IDDESCACREPR'] == 'D')? 'D' : 'A';
                    $this->dataSourceManager->persist(new DataSet('precosdiferenciadosatu', array($row)));
                }
            }
        } catch(\Exception $e){
            var_dump($e);
        }   
    }
}