<?php

namespace Teknisa\MAN\Services;

use Doctrine\ORM\EntityManager;
use Teknisa\MAN\Utilities;
use \Zeedhi\Framework\Util\Functions;

class RelCompCredPessoalService {

	public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }
    
    public function find($conditions) {
        $result = [];
        if(isset($conditions['DTENTRVENDA'][0]) && !empty($conditions['DTENTRVENDA'][1])){
            $conditions = self::prepareParameters($conditions);
            $params = array(
                ":TCDFILIAL"  => $conditions['TCDFILIAL'],
                ":TCDCLIENTE" => $conditions['TCDCLIENTE'],
                ":CDFILIAL"   => $conditions['CDFILIAL'],
                ":CDCLIENTE"  => $conditions['CDCLIENTE'],
                ":CDCONSUMIDOR"  => $conditions['CDCONSUMIDOR'],
                ":TCDCONSUMIDOR"  => $conditions['TCDCONSUMIDOR'],
                ":CDTIPOCONS"  => $conditions['CDTIPOCONS'],
                ":TCDTIPOCONS"  => $conditions['TCDTIPOCONS'],
                ":DTINI" => $conditions['DATAINI'],
                ":DTFIN" => $conditions['DATAFIN'],
                ":NRORG" => $conditions['NRORG']
            );
     		return $this->entityManager->getConnection()->fetchAll(self::GET_CRED_PESSOAL, $params);
        } 
        return $result;
    }
    
    private function prepareParameters($conditions){
        if(!Functions::arrayKeyExists('CDFILIAL', $conditions)) {
            $conditions['CDFILIAL'] = NULL;
            $conditions['TCDFILIAL'] = 'T';
        } else {
            $conditions['CDFILIAL'] = $conditions['CDFILIAL'];
            $conditions['TCDFILIAL'] = NULL;
        }
        if(!Functions::arrayKeyExists('CDCLIENTE', $conditions)) {
            $conditions['CDCLIENTE'] = NULL;
            $conditions['TCDCLIENTE'] = 'T';
        } else {
            $conditions['CDCLIENTE'] = implode('_', $conditions['CDCLIENTE']);
            $conditions['TCDCLIENTE'] = NULL;
        }
        if(Functions::arrayKeyExists('DTENTRVENDA', $conditions)) {
            $conditions['DATAINI'] = $conditions['DTENTRVENDA'][0];
            $conditions['DATAFIN'] = $conditions['DTENTRVENDA'][1];
            unset($conditions['DTENTRVENDA']);
        }
        if(!Functions::arrayKeyExists('CDCONSUMIDOR', $conditions)) {
            $conditions['CDCONSUMIDOR'] = NULL;
            $conditions['TCDCONSUMIDOR'] = 'T';
        } else {
            $conditions['CDCONSUMIDOR'] =  implode('_', $conditions['CDCONSUMIDOR']);
            $conditions['TCDCONSUMIDOR'] = NULL;
        }
        if(!Functions::arrayKeyExists('CDTIPOCONS', $conditions)) {
            $conditions['CDTIPOCONS'] = NULL;
            $conditions['TCDTIPOCONS'] = 'T';
        } else {
            $conditions['CDTIPOCONS'] = implode('_', $conditions['CDTIPOCONS']);
            $conditions['TCDTIPOCONS'] = NULL;
        }
        return $conditions;
    }
        
  const GET_CRED_PESSOAL = "
    SELECT 
        CL.CDCLIENTE, CL.NMRAZSOCCLIE, TRUNC(EX.DTMOVEXTCONS) AS DTMOVEXTCONS, CX.CDCAIXA,
        CO.CDCONSUMIDOR, CO.NMCONSUMIDOR, FI.CDFILIAL, FI.NMFILIAL,
        SUM(EX.VRMOVEXTCONS) AS VRMOVEXTCONS, EX.CDFAMILISALD, FA.NMFAMILISALD,
        CASE WHEN DSOPEEXTCONS LIKE '%FOS%' THEN '(FOS)'
        WHEN DSOPEEXTCONS LIKE '%EfeCred%' THEN '(CASH-EFE)'
        WHEN DSOPEEXTCONS LIKE '%NoCash (Cartao)%' THEN '(CASH-CAR)'
        WHEN DSOPEEXTCONS LIKE '%VND%' THEN '(VND)'
        WHEN DSOPEEXTCONS LIKE '%CREDITO%' THEN '(VND)'
        ELSE DSOPEEXTCONS
        END AS TIPO, 
        CX.CDCAIXA || NVL2(CX.CDCAIXA, ' - ', '') || CX.NMCAIXA AS LABELCAIXA,
        CO.CDCONSUMIDOR || ' - ' || CO.NMCONSUMIDOR AS LABELCONSUMIDOR,
        CL.CDCLIENTE || ' - ' || CL.NMRAZSOCCLIE AS LABELCLIENTE,
        FI.CDFILIAL || ' - ' || FI.NMFILIAL AS LABELFILIAL,
        TR.CDTIPORECE, TR.NMTIPORECE
        FROM
        EXTRATOCONS EX, CLIENTE CL, CONSUMIDOR CO, FAMILIASALDO FA, FILIAL FI, TIPORECE TR, CAIXA CX
        WHERE (EX.CDFILIAL = :CDFILIAL OR EX.CDFILIAL IS NULL)
        AND (EX.CDFILIAL = FI.CDFILIAL(+))
        AND (TRUNC(EX.DTMOVEXTCONS) BETWEEN :DTINI AND :DTFIN)
        AND (EX.IDTPMOVEXT = 'C')
        AND (EX.VRMOVEXTCONS <> 0)
        AND (CL.CDCLIENTE = EX.CDCLIENTE)
        AND ((INSTR(:CDCLIENTE, CL.CDCLIENTE) > 0) OR (:TCDCLIENTE = 'T'))
        AND (CO.CDCLIENTE = EX.CDCLIENTE)
        AND (CO.CDCONSUMIDOR = EX.CDCONSUMIDOR)
        AND (EX.CDFAMILISALD = FA.CDFAMILISALD) 
        AND ((INSTR(:CDCONSUMIDOR, CO.CDCONSUMIDOR) <> 0) OR (:TCDCONSUMIDOR = 'T'))
        AND ((INSTR(:CDTIPOCONS, CO.CDTIPOCONS) <> 0) OR (:TCDTIPOCONS = 'T'))
        
        AND (EX.CDTIPORECE = TR.CDTIPORECE(+))
        AND (EX.CDFILIAL = CX.CDFILIAL (+))
        AND (EX.CDCAIXA = CX.CDCAIXA (+))
        AND ((DSOPEEXTCONS LIKE '%FOS - Crédito%') OR 
        (DSOPEEXTCONS LIKE '%EfeCred%') OR 
        (DSOPEEXTCONS = 'Crédito VND') OR
        (DSOPEEXTCONS LIKE '%CREDITO%') OR 
        (DSOPEEXTCONS LIKE '%Credito NoCash%'))
        GROUP BY
        CL.CDCLIENTE, CL.NMRAZSOCCLIE, TRUNC(EX.DTMOVEXTCONS), CX.CDCAIXA,
        CO.CDCONSUMIDOR, CO.NMCONSUMIDOR, EX.CDFAMILISALD, FA.NMFAMILISALD, 
        CASE WHEN DSOPEEXTCONS LIKE '%FOS%' THEN '(FOS)'
        WHEN DSOPEEXTCONS LIKE '%EfeCred%' THEN '(CASH-EFE)'
        WHEN DSOPEEXTCONS LIKE '%NoCash (Cartao)%' THEN '(CASH-CAR)'
        WHEN DSOPEEXTCONS LIKE '%VND%' THEN '(VND)'
        WHEN DSOPEEXTCONS LIKE '%CREDITO%' THEN '(VND)'
        ELSE DSOPEEXTCONS
        END,
        FI.CDFILIAL, FI.NMFILIAL, TR.CDTIPORECE, TR.NMTIPORECE, CX.NMCAIXA
        ORDER BY
        FI.CDFILIAL, CX.CDCAIXA, CL.CDCLIENTE, CL.NMRAZSOCCLIE, TRUNC(EX.DTMOVEXTCONS), 
        CO.CDCONSUMIDOR, CO.NMCONSUMIDOR, EX.CDFAMILISALD, FA.NMFAMILISALD
  ";
}